[![Visitor](https://visitor-badge.laobi.icu/badge?page_id=public-sonjj/public-sonjj)](https://github.com/public-sonjj) [![GitHub followers](https://img.shields.io/github/followers/public-sonjj.svg?style=social&label=Follow)](https://github.com/public-sonjj?tab=followers)![YouTube Channel Subscribers](https://img.shields.io/youtube/channel/subscribers/UCIevahX9MAHLL321q_x9-RQ?style=social)

# Hey!, I am Sonjj
Currently I am a Coder and a Webmaster living and working in Hue city, Vietnam. My favorite day to day work is making tools or solutions to help optimize boring tasks on the computer.

## Tools and languages 
![](https://img.shields.io/badge/-Docker-46a2f1?style=flat-square&logo=docker&logoColor=white) ![](https://img.shields.io/badge/-VisualStudio-5C2D91?style=flat-square&logo=VisualStudio&logoColor=white) ![](https://img.shields.io/badge/-php-777BB4?style=flat-square&logo=php&logoColor=white) ![](https://img.shields.io/badge/-javascript-F7DF1E?style=flat-square&logo=javascript&logoColor=black) ![](https://img.shields.io/badge/-airtable-18BFFF?style=flat-square&logo=airtable&logoColor=white) ![](https://img.shields.io/badge/-mysql-4479A1?style=flat-square&logo=mysql&logoColor=white) ![](https://img.shields.io/badge/-github-181717?style=flat-square&logo=github&logoColor=white) ![](https://img.shields.io/badge/-html5-E34F26?style=flat-square&logo=html5&logoColor=white) ![](https://img.shields.io/badge/-tailwindcss-06B6D4?style=flat-square&logo=tailwindcss&logoColor=white) ![](https://img.shields.io/badge/-python-3776AB?style=flat-square&logo=python&logoColor=white) ![](https://img.shields.io/badge/-nginx-009639?style=flat-square&logo=nginx&logoColor=white) ![](https://img.shields.io/badge/-vuejs-4FC08D?style=flat-square&logo=vue.js&logoColor=white) ![](https://img.shields.io/badge/-laravel-FF2D20?style=flat-square&logo=laravel&logoColor=white)

## My project
**Sonjj Tool**  is the name of a project I've had for a long time, an online anonymity toolkit. This project is just getting started, here are some of the tools that are already in the works.


| Name | Description | OS/app &nbsp;&nbsp;&nbsp; |
| --------------- | --------------- | :--------- |
| [Temp Mail](https://smailpro.com "Temp Mail") | Instantly create a temporary email address to protect you from spam, phishing and malware. No commitments and no risks. | [![Temp Mail](https://img.shields.io/badge/web-live-green "Temp Mail")](https://smailpro.com "Temp Mail")  |
| [Receive SMS Online](https://smser.net "Receive SMS Online") | Our phone numbers will help you verify registration of various sites. Or you want to receive a message that does not want to reveal your real phone number. Try our service now. | [![Receive Sms Online](https://img.shields.io/badge/web-live-green "Receive Sms Online")](https://smser.net "Receive Sms Online")   |
| [Username generator](https://ugener.com "Username generator") | The best username generator out there. Simple, fast, free are the goals that we want to bring to you. Keep your personal information away from hackers. |   [![Username Generate](https://img.shields.io/badge/web-live-green "Username Generate")](https://ugener.com "Username Generate")  |
| [Email Checker](https://ychecker.com "Email Checker") | Ychecker is a tool that helps you to check if an email address exists or not. | [![Email Checker](https://img.shields.io/badge/web-live-green "Email Checker")](https://ychecker.com "Email Checker")  |
| [Credit Card Generator](https://cardgener.com "Credit Card Generator") | Credit card number generator for all major brands and also for validating them using the Luhn algorithm. | [![Credit Card Generator](https://img.shields.io/badge/web-live-green "Credit Card Generator")](https://cardgener.com "Credit Card Generator") |
|[best free VPN](https://teahog.com/ "best free VPN") | We provide the best free VPN search engine for you. Search engines according to many different criteria |  [![Best VPN free](https://img.shields.io/badge/web-live-green "Best VPN free")](https://teahog.com "Best VPN free")  |

**Sonjj Solution**: This project will offer a series of solutions to optimize and automate boring tasks on computers. For example, you are managing hundreds of Gmail accounts, how can you log in and check or change your password in bulk, you are managing hundreds of backlinks how can you check which backlinks are still available? there are many other jobs. Currently this project is in beta, I'm trying to get it to you guys as soon as possible.
